@@ -1,6 +1,7 @@
 from transcriptor.job import Job
 from transcriptor.markers import Marker
 from transcriptor.speakers import Speaker
+from transcriptor.alternatives import Alternative
 
 import boto3
 import more_itertools
@@ -35,6 +36,16 @@ def add_marker(segment: typing.Sequence, *, has_speakers:bool=False) -> Marker:
                 )
 
 
+def add_alternative(segment:typing.Dict) -> Alternative:
+
+    return Alternative(
+            content = segment['alternatives'][0]['content'],
+            confidence = float(segment['alternatives'][0]['confidence']),
+            start_time = float(segment['start_time']),
+            end_time = float(segment['end_time']),
+            )
+
+
 def from_job(job_name: str) -> Job:
     """Create a Job Object based on the TranscriptiobJobName"""
     job = transcribe.get_transcription_job(TranscriptionJobName=job_name)
@@ -46,8 +57,6 @@ def from_uri(uri) -> Job:
     response = requests.get(uri)
     response.raise_for_status()
     transcription = response.json()
-    name = transcription['jobName']
-    base_text = transcription['results']['transcripts'][0]['transcript']
 
     if 'speaker_labels' in transcription['results']:
         labels = transcription['results']['speaker_labels']
@@ -62,9 +71,14 @@ def from_uri(uri) -> Job:
         )
         markers = [add_marker(x) for x in items_segments]
 
+    transcription_items = [
+            add_alternative(x) for x in transcription['results']['items']
+            ]
+
     return Job(
-            base_text=base_text,
-            name=name,
+            base_text = transcription['results']['transcripts'][0]['transcript'],
+            transcription_items = transcription['results']['items'],
+            name = transcription['jobName'],
             transcription=transcription,
             speakers = speakers,
             markers = markers,
